@@ -9,3 +9,6 @@ TEST_OUTPUTS_DIR = TESTS_DIR / "out"
 RDF_TESTS_DIR = CONFORMANCE_TESTS_DIR / "rdf"
 RDF_FROM_JELLY_TESTS_DIR = RDF_TESTS_DIR / "from_jelly"
 RDF_TO_JELLY_TESTS_DIR = RDF_TESTS_DIR / "to_jelly"
+
+RDF_FROM_JELLY_MANIFEST = RDF_FROM_JELLY_TESTS_DIR / "manifest.ttl"
+RDF_TO_JELLY_MANIFEST = RDF_TO_JELLY_TESTS_DIR / "manifest.ttl"
